@@ -461,17 +461,17 @@ class UCR(predict_system.TextSystem):
             model_type = 'torch_mobile' if lang != 'ch_sim' else model_type
             postprocess_params.rec_char_dict_path = model_urls[model_type]['rec'][lang][
                 'dict_path']
-            model_type = postprocess_params.model_type
+            model_type = backend + '_' + type
         
         # download model
         model_type = 'torch_server' if det_algorithm == 'CRAFT' else model_type
         det_path, det_cfg_path = maybe_download(os.path.join(BASE_DIR, '{}/det'.format(VERSION)), model_urls[model_type]['det'][det_algorithm]['url'])
-        model_type = postprocess_params.model_type
+        model_type = backend + '_' + type
         
         model_type = 'torch_mobile' if lang != 'ch_sim' else model_type
         rec_path, rec_cfg_path = maybe_download(os.path.join(BASE_DIR, '{}/rec/{}'.format(VERSION, lang)),
                        model_urls[model_type]['rec'][lang]['url'])
-        model_type = postprocess_params.model_type
+        model_type = backend + '_' + type
         
         cls_path, cls_cfg_path = maybe_download(os.path.join(BASE_DIR, '{}/cls'.format(VERSION)), model_urls['torch_mobile']['cls']['url'])
         
